@@ -9,7 +9,7 @@ matlab <- function() {
   "and bear the same signature as their Matlab cousins as far as possible:",
   "
   accumarray, acot, acoth, acsc, acsch, and, angle, ans, arrayfun, asec, asech,
-  beep, blank, blkdiag, bsxfun,
+  beep, bernoulli, blank, blkdiag, bsxfun,
   cart2pol, cart2sph, cd, ceil, circshift, clear, compan, cond, conv,
       cot, coth, cross, csc, csch, cumtrapz,
   dblquad, deblank, deconv, deg2rad, detrend, deval, disp, dot,
@@ -26,7 +26,7 @@ matlab <- function() {
       lsqlin, lsqnonlin, lsqnonneg, lu,
   magic, meshgrid, mkpp, mldivide, mod, mrdivide,
   nchoosek, ndims, nextpow2, nnz, normest, nthroot, null, num2str, numel,
-  ode23, ones, or, orth,
+  ode23, ode23s, ones, or, orth,
   pascal, pchip, pdist, pdist2, peaks, perms, piecewise, pinv, plotyy,
       pol2cart,polar, polyfit, polyint, polylog, polyval, pow2, ppval,
       primes, psi, pwd,
@@ -35,7 +35,7 @@ matlab <- function() {
       rem, repmat, roots, rosser, rot90, rref, runge,
   sec, sech, semilogx, semilogy, sinc, size, sortrows, sph2cart, sqrtm,
       squareform, std, str2num, strcat, strcmp, strcmpi, strfind, strfindi,
-      strjust, strrep, subspace,
+      strjust, subspace,
   tic, toc, trapz, tril, trimmean, triplequad, triu,
   vander, vectorfield, ver,
   what, who, whos, wilkinson,
@@ -45,7 +45,7 @@ matlab <- function() {
   "avoid shadowing functions from R base or one of its recommended packages:",
   "
   Diag, factors, finds, Fix, Imag, Lcm, Mode, Norm, nullspace (null),
-  Poly, Rank, Real, Reshape, strTrim, Toeplitz, Trace, uniq (unique).", 
+  Poly, Rank, Real, Reshape, strRep, strTrim, Toeplitz, Trace, uniq (unique).", 
   "",
   "To use 'ans' instead of 'ans()' (i.e., as is common practice in Matlab)",
   "type (and similar for other Matlab commands):",
